@@ -30,4 +30,8 @@ void spi_atk_deregister_event_listeners (void);
 void spi_atk_tidy_windows (void);
 
 gboolean spi_event_is_subtype (gchar **needle, gchar **haystack);
+
+extern GMainContext *spi_context;
+guint spi_idle_add(GSourceFunc    function, gpointer       data);
+guint spi_timeout_add_seconds (gint interval, GSourceFunc function, gpointer    data);
 #endif /* EVENT_H */
